@@ -17,6 +17,7 @@ __all__ = [
     'EntryHTMLView',
     'EntryResource',
     'HTTPResource',
+    'JSONDate',
     'JSONItem',
     'ReadOnlyResource',
     'RedirectResource',
@@ -29,8 +30,7 @@ __all__ = [
     'WADL_SCHEMA_FILE',
     ]
 
-
-from datetime import datetime, date
+from collections import OrderedDict
 from email.utils import formatdate
 import copy
 from operator import itemgetter
@@ -72,6 +72,7 @@ from zope.interface import (
     providedBy,
     Interface,
     )
+from zope.interface.common.idatetime import IDate
 from zope.interface.common.sequence import IFiniteSequence
 from zope.interface.interfaces import (
     ComponentLookupError,
@@ -161,20 +162,7 @@ def decode_value(value):
     elif isinstance(value, bytes):
         return value.decode("utf-8")
     else:
-        return six.text_type(value)
-
-
-def encode_value(value):
-    """Return a UTF-8 string corresponding to `value`.
-
-    Non-unicode strings are assumed to be UTF-8 already.
-    """
-    if isinstance(value, six.text_type):
-        return value.encode("utf-8")
-    elif isinstance(value, bytes):
-        return value
-    else:
-        return bytes(value)
+        return simplejson.dumps(value, cls=ResourceJSONEncoder)
 
 
 def _default_html_renderer(value):
@@ -222,8 +210,6 @@ class ResourceJSONEncoder(simplejson.encoder.JSONEncoderForHTML):
 
     def default(self, obj):
         """Convert the given object to a simple data structure."""
-        if isinstance(obj, datetime) or isinstance(obj, date):
-            return obj.isoformat()
         if isProxy(obj):
             # We have a security-proxied version of a built-in
             # type. We create a new version of the type by copying the
@@ -258,6 +244,19 @@ class JSONItem:
         return str(self.context.title)
 
 
+@implementer(IJSONPublishable)
+@adapter(IDate)
+class JSONDate:
+    """JSONPublishable adapter for date/datetime."""
+
+    def __init__(self, context):
+        self.context = context
+
+    def toDataForJSON(self, media_type):
+        """See `IJSONPublishable`."""
+        return self.context.isoformat()
+
+
 @implementer(IHTTPResource)
 class RedirectResource(URLDereferencingMixin):
     """A resource that redirects to another URL."""
@@ -940,20 +939,24 @@ class ReadWriteResource(HTTPResource):
                 self.request.response.setHeader("Allow", allow_string)
         except Exception as e:
             exception_info = sys.exc_info()
-            view = getMultiAdapter((e, self.request), name="index.html")
             try:
-                ws_view = IWebServiceExceptionView(view)
-            except TypeError:
-                # There's a view for this exception, but it's not one
-                # we can understand. It was probably designed for a
-                # web application rather than a web service. We'll
-                # re-raise the exception, let the publisher look up
-                # the view, and hopefully handle it better.  Note the careful
-                # reraising that ensures the original traceback is preserved.
-                if six.PY3:
-                    six.raise_from(exception_info[1], None)
-                else:
-                    six.reraise(*exception_info)
+                view = getMultiAdapter((e, self.request), name="index.html")
+                try:
+                    ws_view = IWebServiceExceptionView(view)
+                except TypeError:
+                    # There's a view for this exception, but it's not one we
+                    # can understand.  It was probably designed for a web
+                    # application rather than a web service.  We'll re-raise
+                    # the exception, let the publisher look up the view, and
+                    # hopefully handle it better.  Note the careful
+                    # reraising that ensures the original traceback is
+                    # preserved.
+                    if six.PY3:
+                        six.raise_from(exception_info[1], None)
+                    else:
+                        six.reraise(*exception_info)
+            finally:
+                del exception_info
 
             self.request.response.setStatus(ws_view.status)
             if ws_view.status // 100 == 4:
@@ -1476,7 +1479,7 @@ class EntryResource(CustomOperationResourceMixin,
         The values in the dictionary may differ depending on the value
         of media_type.
         """
-        data = {}
+        data = OrderedDict()
         data['self_link'] = absoluteURL(self.context, self.request)
         if self.adapter_utility.publish_web_link:
             # Objects in the web service correspond to pages on some website.
