@@ -58,7 +58,7 @@ def load_tests(loader, tests, pattern):
         }
     suite = doctest.DocFileSuite(
         *doctest_files, optionflags=DOCTEST_FLAGS, globs=globs,
-        checker=checker)
+        encoding='UTF-8', checker=checker)
     suite.layer = WSGILayer
     tests.addTest(suite)
     return tests
