@@ -11,8 +11,9 @@ import os
 import doctest
 from pkg_resources import resource_filename
 
-from zope.component import getUtility
 from van.testing.layer import zcml_layer, wsgi_intercept_layer
+from zope.component import getUtility
+from zope.testing import renormalizing
 
 from lazr.restful.example.multiversion.root import (
     MultiversionWebServiceRootResource)
@@ -27,6 +28,9 @@ DOCTEST_FLAGS = (
     doctest.REPORT_NDIFF)
 
 
+checker = renormalizing.OutputChecker()
+
+
 class FunctionalLayer:
     zcml = os.path.abspath(resource_filename(
         'lazr.restful.example.multiversion', 'site.zcml'))
@@ -55,7 +59,8 @@ def load_tests(loader, tests, pattern):
         'print_function': print_function,
         }
     suite = doctest.DocFileSuite(
-        *doctest_files, optionflags=DOCTEST_FLAGS, globs=globs)
+        *doctest_files, optionflags=DOCTEST_FLAGS, globs=globs,
+        checker=checker)
     suite.layer = WSGILayer
     tests.addTest(suite)
     return tests
