@@ -24,6 +24,7 @@ __all__ = [
     'VocabularyLookupFieldMarshaller',
     ]
 
+from collections import OrderedDict
 from datetime import datetime
 from io import BytesIO
 import re
@@ -409,6 +410,13 @@ class DateTimeFieldMarshaller(SimpleFieldMarshaller):
             # JSON will serialize '20090131' as a number
             raise ValueError("Value doesn't look like a date.")
 
+    def unmarshall(self, entry, value):
+        """See `IFieldMarshaller`.
+
+        Represent the datetime in ISO 8601 format.
+        """
+        return None if value is None else value.isoformat()
+
 
 class DateFieldMarshaller(DateTimeFieldMarshaller):
     """A marshaller that transforms its value into a date object."""
@@ -572,7 +580,9 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
         """
         if value is None:
             return value
-        return dict(
+        # Use an ordered dict so that fields using this marshaller have a
+        # stable ETag.
+        return OrderedDict(
             (self.key_marshaller.unmarshall(entry, key),
             self.value_marshaller.unmarshall(entry, val))
                for key, val in value.items())
