@@ -21,6 +21,7 @@ __all__ = [
     'WebServiceTestPublication',
     ]
 
+from collections import OrderedDict
 from email.utils import quote as email_quote
 import io
 import random
@@ -193,6 +194,16 @@ def pformat_value(value):
             return "'%s'" % value.replace("'", "\\'")
     elif isinstance(value, list):
         return '[' + ', '.join(pformat_value(item) for item in value) + ']'
+    elif isinstance(value, OrderedDict):
+        # WebServiceResponseWrapper.jsonBody turns JSON objects into
+        # OrderedDicts, but for doctest compatibility we just want to
+        # re-sort and render these as if they were ordinary dicts.
+        return (
+            '{' +
+            ', '.join(
+                '%s: %s' % (pformat_value(k), pformat_value(v))
+                for k, v in sorted(value.items())) +
+            '}')
     else:
         return repr(value)
 
@@ -539,7 +550,7 @@ class WebServiceResponseWrapper(ProxyBase):
         """Return the body of the web service request as a JSON document."""
         body = six.ensure_text(self.body)
         try:
-            return simplejson.loads(body)
+            return simplejson.loads(body, object_pairs_hook=OrderedDict)
         except ValueError:
             # Return a useful ValueError that displays the problematic
             # string, instead of one that just says the string wasn't
