@@ -948,8 +948,8 @@ class TestRequireExplicitVersions(TestCaseWithWebServiceFixtures):
             *self.utility.active_versions)
         interface_10 = interfaces[0].object
         interface_20 = interfaces[1].object
-        self.assertEqual(interface_10.names(), ['field'])
-        self.assertEqual(interface_20.names(), ['field'])
+        self.assertEqual(list(interface_10.names()), ['field'])
+        self.assertEqual(list(interface_20.names()), ['field'])
 
     def test_field_exported_as_of_later_version_is_not_exported_in_earlier_versions(self):
         # If you export a field as_of version 2.0, it's not present in
@@ -959,8 +959,8 @@ class TestRequireExplicitVersions(TestCaseWithWebServiceFixtures):
             *self.utility.active_versions)
         interface_10 = interfaces[0].object
         interface_20 = interfaces[1].object
-        self.assertEqual(interface_10.names(), [])
-        self.assertEqual(interface_20.names(), ['field'])
+        self.assertEqual(list(interface_10.names()), [])
+        self.assertEqual(list(interface_20.names()), ['field'])
 
     def test_field_not_exported_using_as_of_fails(self):
         # If you export a field without specifying as_of, you get an
