@@ -169,9 +169,10 @@ class ErrorsTestCase(unittest.TestCase):
         resource = self._setup_non_web_service_exception()
         try:
             resource()
-        except:
-            pass
-        self.assertTrue('raise exception_class()' in traceback.format_exc())
+        except Exception:
+            self.assertIn('raise exception_class()', traceback.format_exc())
+        else:
+            self.fail('No exception raised.')
 
     def test_passing_bad_things_to_expose(self):
         # The expose function only accepts instances of exceptions.  It
@@ -192,12 +193,16 @@ class ErrorsTestCase(unittest.TestCase):
             EntryAdapterUtility.forSchemaInterface(
                 IMyEntry, self.beta_request)
         except Exception as e:
-            pass
-        self.assertTrue(isinstance(e, Exception))
+            self.assertTrue(isinstance(e, Exception))
 
-        # The exception's message explains what went wrong.
-        self.assertTrue(str(e),
-            'No IEntry adapter found for IMyEntry (web service version: beta).')
+            # The exception's message explains what went wrong.
+            self.assertTrue(str(e),
+                'No IEntry adapter found for IMyEntry '
+                '(web service version: beta).')
+        else:
+            self.fail(
+                'EntryAdapterUtility.forSchemaInterface did not raise an '
+                'exception')
 
     def test_missing_adapter_whence(self):
         # The UnknownEntryAdapter exception has a "whence" attribute that
@@ -221,12 +226,14 @@ class ErrorsTestCase(unittest.TestCase):
         resource = TestResource(broken, request)
         try:
             resource()
-        except:
-            pass
-        self.assertTrue(
-            "raise RuntimeError('something broke')" in traceback.format_exc())
+        except Exception:
+            self.assertIn(
+                "raise RuntimeError('something broke')",
+                traceback.format_exc())
+        else:
+            self.fail('No exception raised.')
 
-    def test_reporting_original_exception_with_no_trackeback(self):
+    def test_reporting_original_exception_with_no_traceback(self):
         # Sometimes an exception won't have an __traceback__ attribute.  The
         # re-raising should still work (bug 854695).
         class TracebacklessException(Exception):
@@ -241,12 +248,12 @@ class ErrorsTestCase(unittest.TestCase):
                 'The resource should not have generated an AttributeError. '
                 'This is probably because something was expecting the '
                 'exception to have a __traceback__ attribute.')
-        except (MemoryError, KeyboardInterrupt, SystemExit):
+        except MemoryError:
             raise
-        except:
-            pass
-
-        self.assertTrue("TracebacklessException" in traceback.format_exc())
+        except Exception:
+            self.assertIn("TracebacklessException", traceback.format_exc())
+        else:
+            self.fail('No exception raised.')
 
 
 class FunctionalLayer:
