@@ -5,8 +5,17 @@ from __future__ import absolute_import, print_function
 
 __metaclass__ = type
 
+from collections import OrderedDict
+from datetime import (
+    date,
+    datetime,
+    )
+import os.path
 import unittest
 
+from pkg_resources import resource_filename
+import pytz
+from van.testing.layer import zcml_layer
 from zope.component import provideUtility
 
 from lazr.restful.interfaces import IWebServiceConfiguration
@@ -20,12 +29,22 @@ from lazr.restful._resource import (
     )
 
 
+class FunctionalLayer:
+    allow_teardown = False
+    zcml = os.path.abspath(resource_filename('lazr.restful', 'ftesting.zcml'))
+
+
+zcml_layer(FunctionalLayer)
+
+
 class TestEntryResourceETags(unittest.TestCase):
     # The EntryResource uses the field values that can be written or might
     # othwerise change as the basis for its ETags.  The make_entry_etag_cores
     # function is passed the data about the fields and returns the read and
     # write cores.
 
+    layer = FunctionalLayer
+
     def test_no_field_details(self):
         # If make_entry_etag_cores is given no field details (because no
         # fields exist), the resulting cores empty strings.
@@ -80,6 +99,28 @@ class TestEntryResourceETags(unittest.TestCase):
             [b'first-not-writable\x00second-not-writable',
              b'first-writable\x00second-writable'])
 
+    def test_collection_fields(self):
+        # Field values that are something other than text or bytes are
+        # encoded using JSON.
+        field_details = [
+            ('list_field',
+             {'writable': False,
+              'value': ['first', 'second']}),
+            ('dict_field',
+             {'writable': False,
+              'value': OrderedDict((('first', 'one'), ('second', 'two')))}),
+            ('date_field',
+             {'writable': False,
+              'value': date(2009, 7, 7)}),
+            ('datetime_field',
+             {'writable': False,
+              'value': datetime(2009, 7, 7, 13, 45, 0, tzinfo=pytz.utc)}),
+            ]
+        self.assertEqual(
+            make_entry_etag_cores(field_details),
+            [b'["first", "second"]\x00{"first": "one", "second": "two"}\x00'
+             b'"2009-07-07"\x00"2009-07-07T13:45:00+00:00"', b''])
+
 
 class TestHTTPResourceETags(unittest.TestCase):
 
